@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::5_0::Bulk;
-$Search::Elasticsearch::Client::5_0::Bulk::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::5_0::Bulk::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Client::5_0::Bulk::VERSION = '6.81';
+use Moo;
 with 'Search::Elasticsearch::Client::5_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -78,7 +77,7 @@ Search::Elasticsearch::Client::5_0::Bulk - A helper module for the Bulk API
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 SYNOPSIS
 
