@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::5_0::Direct::Cat;
-$Search::Elasticsearch::Client::5_0::Direct::Cat::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::5_0::Direct::Cat::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Client::5_0::Direct::Cat::VERSION = '6.81';
+use Moo;
 with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
@@ -43,7 +42,7 @@ Search::Elasticsearch::Client::5_0::Direct::Cat - A client for running cat debug
 
 =head1 VERSION
 
-version 6.80_1
+version 6.81
 
 =head1 DESCRIPTION
 
