@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::5_0::Role::Bulk;
-$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '6.81';
+use Moo::Role;
 requires 'add_action', 'flush';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -275,7 +274,7 @@ Search::Elasticsearch::Client::5_0::Role::Bulk - Provides common functionality t
 
 =head1 VERSION
 
-version 6.80_01
+version 6.81
 
 =head1 AUTHOR
 
