@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::5_0::TestServer;
-$Search::Elasticsearch::Client::5_0::TestServer::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::5_0::TestServer::VERSION = '6.8001';use strict;
+$Search::Elasticsearch::Client::5_0::TestServer::VERSION = '6.81';
+use strict;
 use warnings;
 
 #===================================
@@ -42,7 +41,7 @@ Search::Elasticsearch::Client::5_0::TestServer - Client-specific backend for Sea
 
 =head1 VERSION
 
-version 6.80_01
+version 6.81
 
 =head1 AUTHOR
 
